package gogitlab

import (
	"encoding/json"
)

const (
	project_issues_url = "/projects/:id/issues"
)

type Milestone struct {
	Id          int    `json:"id,omitempty"`
	IId         int    `json:"iid,omitempty"`
	ProjectId   int    `json:"project_id,omitempty"`
	Title       string `json:"title,omitempty"`
	Description string `json:"description,omitempty"`
	DueDate     string `json:"due_date,omitempty"`
	State       string `json:"state,omitempty"`
	CreatedAt   string `json:"created_at"`
	UpdatedAt   string `json:"updated_at,omitempty"`
}

type Issue struct {
	Id          int        `json:"id"`
	IId         int        `json:"iid"`
	ProjectId   int        `json:"project_id,omitempty"`
	Title       string     `json:"title,omitempty"`
	Description string     `json:"description,omitempty"`
	Labels      []string   `json:"labels,omitempty"`
	Milestone   *Milestone `json:"milestone,omitempty"`
	Assignee    *User      `json:"assignee,omitempty"`
	Author      *User      `json:"author,omitempty"`
	State       string     `json:"state,omitempty"`
	CreatedAt   string     `json:"created_at,omitempty"`
	UpdatedAt   string     `json:"updated_at,omitempty"`
}

type IssueRequest struct {
	Title       string `json:"title"`
	Description string `json:"description,omitempty"`
	AssigneeId  int    `json:"assignee_id,omitempty"`
	MilestoneId int    `json:"milestone_id,omitempty"`
	Labels      string `json:"labels,omitempty"`
}

func (g *Gitlab) AddIssue(projectId string, req *IssueRequest) (issue *Issue, err error) {
	params := map[string]string{
		":id": projectId,
	}
	u := g.ResourceUrl(project_issues_url, params)

	encodedRequest, err := json.Marshal(req)
	if err != nil {
		return
	}

	data, err := g.buildAndExecRequest("POST", u, encodedRequest)
	if err != nil {
		return
	}

	issue = new(Issue)
	err = json.Unmarshal(data, issue)
	if err != nil {
		panic(err)
	}
	return
}
